Builtin actions - Faber 1.0 documentation

###  |

# Builtin actions

The following actions are provided by Faber and its built-in tools.

`touch`

  Touch a file, i.e. either create it if it doesn't exist, or update its modification time.

`copy`

  Copy a file.

`remove`

  Remove a file.

`cc.makedep`

  Inject header dependencies for the given target by parsing the source.

`cc.compile`

  Compile a C file into an object file.

`cc.archive`

  Generate an archive (static library) from the given object file(s).

`cc.link`

  Link the given object file(s) into shared library.

`cxx.makedep`

  Inject header dependencies for the given target by parsing the source.

`cxx.compile`

  Compile a C++ file into an object file.

`cxx.archive`

  Generate an archive (static library) from the given object file(s).

`cxx.link`

  Link the given object file(s) into shared library.

`gcc.makedep`

  Inject header dependencies for the given target by parsing the source.

`gcc.compile`

  Compile a C file into an object file.

`gcc.archive`

  Generate an archive (static library) from the given object file(s).

`gcc.link`

  Link the given object file(s) into shared library.

`gxx.makedep`

  Inject header dependencies for the given target by parsing the source.

`gxx.compile`

  Compile a C++ file into an object file.

`gxx.archive`

  Generate an archive (static library) from the given object file(s).

`gxx.link`

  Link the given object file(s) into shared library.

`clang.makedep`

  Inject header dependencies for the given target by parsing the source.

`clang.compile`

  Compile a C file into an object file.

`clang.archive`

  Generate an archive (static library) from the given object file(s).

`clang.link`

  Link the given object file(s) into shared library.

`clangxx.makedep`

  Inject header dependencies for the given target by parsing the source.

`clangxx.compile`

  Compile a C++ file into an object file.

`clangxx.archive`

  Generate an archive (static library) from the given object file(s).

`clangxx.link`

  Link the given object file(s) into shared library.

`msvc.makedep`

  Inject header dependencies for the given target by parsing the source.

`msvc.compile`

  Compile a C or C++ file into an object file.

`msvc.archive`

  Generate an archive (static library) from the given object file(s).

`msvc.link`

  Link the given object file(s) into shared library.

`python.run`

  Run the given Python script.